==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowUpRightFromSquare.md <==
# ArrowUpRightFromSquare


```text
fontawesome-6/Solid/ArrowUpRightFromSquare
```

```text
include('fontawesome-6/Solid/ArrowUpRightFromSquare')
```



| Illustration | ArrowUpRightFromSquare |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowUpRightFromSquare.png) | ![illustration for ArrowUpRightFromSquare](../../fontawesome-6/Solid/ArrowUpRightFromSquare.Local.png) |




## ArrowUpRightFromSquare

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpRightFromSquare
include('fontawesome-6/Solid/ArrowUpRightFromSquare')

' renders the element
ArrowUpRightFromSquare('ArrowUpRightFromSquare', 'Arrow Up Right From Square', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpRightFromSquare
include('fontawesome-6/Solid/ArrowUpRightFromSquare')

' renders the element
ArrowUpRightFromSquare('ArrowUpRightFromSquare', 'Arrow Up Right From Square', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/ArrowUpRightFromSquare.md <==
# ArrowUpRightFromSquare


```text
fontawesome-6/Solid/ArrowUpRightFromSquare
```

```text
include('fontawesome-6/Solid/ArrowUpRightFromSquare')
```



| Illustration | ArrowUpRightFromSquare |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowUpRightFromSquare.png) | ![illustration for ArrowUpRightFromSquare](../../fontawesome-6/Solid/ArrowUpRightFromSquare.Local.png) |




## ArrowUpRightFromSquare

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpRightFromSquare
include('fontawesome-6/Solid/ArrowUpRightFromSquare')

' renders the element
ArrowUpRightFromSquare('ArrowUpRightFromSquare', 'Arrow Up Right From Square', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpRightFromSquare
include('fontawesome-6/Solid/ArrowUpRightFromSquare')

' renders the element
ArrowUpRightFromSquare('ArrowUpRightFromSquare', 'Arrow Up Right From Square', 'an optional tech label', 'an optional description')
@enduml
```
